@@ -5,9 +5,8 @@ import pickle
 from typing import List
 
 import numpy as np
-import pandas as pd
 import tensorflow as tf
-from model_data_util.create_tt_data.model_data_convert import convertRawDataToModel, convertModelToRawData, \
+from model_data_util.create_tt_data.model_data_convert import convertModelToRawData, \
     preprocessRawData
 
 from TTBenchmark.check_environment import check_env_info, in_notebook
@@ -47,9 +46,12 @@ def run_benchmark(
         model_types: list = None,
         predict_type: str = "median",
         gdrive_path=GDRIVE_PATH,
-        env_path=None
+        env_path=None,
+        upper_limit_per_type=None,
+        benchmarks=None
 ) -> dict:
     """
+
     :param tt_predictor: a model can predict training time
     :param get_feature_func: a function used to grab features from tensorflow models
     :param kwargs: by default, all arguments (except get_feature_func and kwargs) passed into run_benchmarks will be added into kwargs;
@@ -57,6 +59,9 @@ def run_benchmark(
     :param model_types: a list of model categories. If None, all models in the matched environment benchmark will be tested
     :param predict_type: must be one of the value "median", "mean", "std"
     :param gdrive_path: the path to the benchmark model file, in default is "/content/drive/MyDrive/benchmark"
+    :param env_path: environment directory path. Only specify value if not testing the current environment
+    :param upper_limit_per_type: the maximum number of benchmark acceptable per model type
+    :param benchmarks: if benchmark was past, it will not load benchmarks
     :return: benchmark data object
     """
     if env_path is None:
@@ -72,10 +77,12 @@ def run_benchmark(
     for model_type in model_types:
         print(f"Testing model type: {model_type}")
         actual_tt_json_path = os.path.join(env_path, model_type, "trained_tt.json")
-        benchmarks = _load_benchmark(actual_tt_json_path)
+        benchmarks = _load_benchmark(actual_tt_json_path, upper_limit_per_type) if benchmarks is None else benchmarks
         kwargs["model_type"] = model_type
         kwargs["actual_tt_json_path"] = actual_tt_json_path
-        for bmmodel in tqdm(benchmarks):
+        print("Start test...")
+        limit = upper_limit_per_type if upper_limit_per_type is not None else len(benchmarks)
+        for bmmodel in tqdm(benchmarks[:limit]):
             kwargs["batch_size"] = bmmodel.fit_kwargs["batch_size"]
             X = get_feature_func(bmmodel.model_info["raw_model"], bmmodel.data["x_shape"], kwargs)
             y_pred = tt_predictor.predict(X).flatten()
@@ -84,11 +91,12 @@ def run_benchmark(
             assert predict_type in bmmodel.actual_tt, f"predict_type must be one of the value {list(bmmodel.actual_tt.keys())}"
             result[model_type][bmmodel.model_info["model_name"]]["tt_actual"] = bmmodel.actual_tt[predict_type]
 
-    return result
+    return result, benchmarks
 
 
 def _load_benchmark(
-        actual_tt_json_path: str
+        actual_tt_json_path: str,
+        upper_limit_per_type: int
 ) -> List[BenchmarkData]:
     """
     json structure:
@@ -105,12 +113,18 @@ def _load_benchmark(
         actual_tt_json = json.load(f)
 
     benchmarks = []
-    for model_name, stat in actual_tt_json.items():
+    dir_path = os.path.dirname(actual_tt_json_path)
+    print("loading benchmarks...")
+    if upper_limit_per_type is None:
+        upper_limit_per_type = len(list(actual_tt_json.keys()))
+    for model_name, stat in tqdm(list(actual_tt_json.items())[:upper_limit_per_type]):
+        model_path = os.path.join(dir_path, model_name)
         bmdata = BenchmarkData()
         bmdata.fit_kwargs = stat["fit_kwargs"]
         bmdata.actual_tt = stat["actual_tt"]
-        bmdata.model_info["raw_model"], training_size, batch_input_shape = convertRawDataToModel(
-            pd.DataFrame(stat["model_df"]))
+        bmdata.model_info["raw_model"] = tf.keras.models.load_model(model_path)
+        training_size = stat["training_size"]
+        batch_input_shape = bmdata.model_info["raw_model"].get_config()["layers"][0]["config"]["batch_input_shape"]
         bmdata.data["x_shape"] = np.array([training_size, *batch_input_shape[1:]])
         bmdata.model_info["model_name"] = model_name
         benchmarks.append(bmdata)
@@ -120,15 +134,9 @@ def _load_benchmark(
 if __name__ == "__main__":
     def get_feature_func(model, x_shape, kwargs):
         training_size = x_shape[0]
-        actual_tt_json_path = kwargs["actual_tt_json_path"]
-        actual_tt_json = json.load(open(actual_tt_json_path))
-        random_key = list(actual_tt_json.keys())[0]
-        columns = list(actual_tt_json[random_key]["model_df"].keys())
-
         padding = kwargs["tt_predictor"].layers[0].input_shape[1]
 
-        batch_input_shape = np.array([kwargs["batch_size"], *x_shape[1:]])
-        df = convertModelToRawData(model, columns, training_size, batch_input_shape)
+        df = convertModelToRawData(model, training_size)
         X = preprocessRawData(df, kwargs["one_hot_enc"], padding).values
         X = X.reshape((-1, *X.shape))
         return X
@@ -139,8 +147,8 @@ if __name__ == "__main__":
     model_path = "/Users/wangqiong/Documents/AIpaca/Code/TT Prediction/benchmark/benchmark_lib/local_data/model"
     gdrive_path = "/Users/wangqiong/Documents/AIpaca/Code/TT Prediction/benchmark/benchmark_lib/local_data"
     tt_predictor = tf.keras.models.load_model(model_path)
-
     one_hot_enc = pickle.load(open(os.path.join(model_path, "one_hot_enc.pkl"), "rb"))
     kwargs = {"one_hot_enc": one_hot_enc}
-    benchmarks = run_benchmark(tt_predictor, get_feature_func, gdrive_path=gdrive_path, kwargs=kwargs)
+    benchmarks = run_benchmark(tt_predictor, get_feature_func, gdrive_path=gdrive_path, kwargs=kwargs,
+                               upper_limit_per_type=None)
     print(benchmarks)
