@@ -4,7 +4,8 @@ import os
 
 import numpy as np
 import tensorflow as tf
-from model_data_util.create_tt_data.model_data_convert import convertModelToRawData, convertRawDataToModel
+from model_data_util.create_tt_data.generate_tt_data import createInputbyModel
+from model_data_util.create_tt_data.model_data_convert import convertRawDataToModel
 
 from TTBenchmark.check_environment import check_env_info, in_notebook
 from TTBenchmark.constant import GDRIVE_PATH
@@ -63,7 +64,6 @@ def _get_benchmark_path(gdrive_path, model_type, fname="trained_tt.json"):
 
 def save_benchmark(
         benchmarks_mini: list,
-        columns: list,
         model_type: str,
         gdrive_path=GDRIVE_PATH,
         replace=True
@@ -112,14 +112,18 @@ def save_benchmark(
             actual_tt_json[model_name] = {}
 
             batch_input_shape = np.array([fit_kwargs["batch_size"], *x_shape[1:]])
-            num_data = x_shape[0]
+            num_data = int(x_shape[0])
 
             item = actual_tt_json[model_name]
-            item["model_df"] = convertModelToRawData(model, columns, num_data, batch_input_shape,
-                                                     num_dim=len(
-                                                         batch_input_shape)).to_dict()  # with no out_dim padding
+
+            x, y = createInputbyModel(model, num_data, batch_input_shape[1:])
+            model.fit(x, y, batch_size=int(batch_input_shape[0]), epochs=1, verbose=False)
+            model_path = _get_benchmark_path(gdrive_path, model_type, model_name)
+            model.save(model_path)
+
             item["actual_tt"] = actual_tt
             item["fit_kwargs"] = fit_kwargs
+            item["training_size"] = num_data
 
     _write_json(actual_tt_json, actual_tt_json_path)
 
@@ -134,7 +138,6 @@ if __name__ == "__main__":
 
     benchmarks_mini = []
     res['X_df'] = [pd.DataFrame(x_df) for x_df in res['X_df']]
-    columns = res['X_df'][0].columns
     model_type = "ffnn_dense_only"
     for i, X_df in enumerate(tqdm(res['X_df'][:10])):
         X_df = pd.DataFrame(X_df)
@@ -152,6 +155,6 @@ if __name__ == "__main__":
             verbose=False
         )
         benchmarks_mini.append(bmdata_mini)
-    save_benchmark(benchmarks_mini, columns, model_type,
+    save_benchmark(benchmarks_mini, model_type,
                    gdrive_path="/Users/wangqiong/Documents/AIpaca/Code/TT Prediction/benchmark/benchmark_lib/local_data",
                    replace=True)
